package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.IndexPartnerConfig;

/**
 * 加入合伙人提示配置Service接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface IIndexPartnerConfigService 
{
    /**
     * 查询加入合伙人提示配置
     * 
     * @param partnerBackground 加入合伙人提示配置主键
     * @return 加入合伙人提示配置
     */
    public IndexPartnerConfig selectIndexPartnerConfigByPartnerBackground(String partnerBackground);

    /**
     * 查询加入合伙人提示配置列表
     * 
     * @param indexPartnerConfig 加入合伙人提示配置
     * @return 加入合伙人提示配置集合
     */
    public List<IndexPartnerConfig> selectIndexPartnerConfigList(IndexPartnerConfig indexPartnerConfig);

    /**
     * 新增加入合伙人提示配置
     * 
     * @param indexPartnerConfig 加入合伙人提示配置
     * @return 结果
     */
    public int insertIndexPartnerConfig(IndexPartnerConfig indexPartnerConfig);

    /**
     * 修改加入合伙人提示配置
     * 
     * @param indexPartnerConfig 加入合伙人提示配置
     * @return 结果
     */
    public int updateIndexPartnerConfig(IndexPartnerConfig indexPartnerConfig);

    /**
     * 批量删除加入合伙人提示配置
     * 
     * @param partnerBackgrounds 需要删除的加入合伙人提示配置主键集合
     * @return 结果
     */
    public int deleteIndexPartnerConfigByPartnerBackgrounds(String[] partnerBackgrounds);

    /**
     * 删除加入合伙人提示配置信息
     * 
     * @param partnerBackground 加入合伙人提示配置主键
     * @return 结果
     */
    public int deleteIndexPartnerConfigByPartnerBackground(String partnerBackground);

    /**
     * 查询加入合伙人提示配置列表
     * @return 加入合伙人提示配置集合
     */
    public List<IndexPartnerConfig> getIndexPartnerConfigList();
}
